==> estateplat-common-1.2.4-20230221.092240-1146-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCxsq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
 * @version 1.0, 2017/5/10
 * @description 不动产查询申请
 */
@Table(name = "bdc_cxsq")
public class BdcCxsq implements Serializable{

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询申请主键
     */
    @Id
    private String cxsqid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 项目主键
     */
    private String proid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 工作流ID
     */
    private String wiid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人
     */
    private String sqr;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人证件号码
     */
    private String sqrzjhm;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询目的
     */
    private String cxmd;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询条件
     */
    private String cxtj;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询内容
     */
    private String cxnr;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询凭证
     */
    private String cxpz;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询结果
     */
    private String cxjg;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请时间
     */
    private Date sqsj;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 备注
     */
    private String bz;

    public String getCxsqid() {
        return cxsqid;
    }

    public void setCxsqid(String cxsqid) {
        this.cxsqid = cxsqid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSqr() {
        return sqr;
    }

    public void setSqr(String sqr) {
        this.sqr = sqr;
    }

    public String getSqrzjhm() {
        return sqrzjhm;
    }

    public void setSqrzjhm(String sqrzjhm) {
        this.sqrzjhm = sqrzjhm;
    }

    public String getCxmd() {
        return cxmd;
    }

    public void setCxmd(String cxmd) {
        this.cxmd = cxmd;
    }

    public String getCxtj() {
        return cxtj;
    }

    public void setCxtj(String cxtj) {
        this.cxtj = cxtj;
    }

    public String getCxnr() {
        return cxnr;
    }

    public void setCxnr(String cxnr) {
        this.cxnr = cxnr;
    }

    public String getCxpz() {
        return cxpz;
    }

    public void setCxpz(String cxpz) {
        this.cxpz = cxpz;
    }

    public String getCxjg() {
        return cxjg;
    }

    public void setCxjg(String cxjg) {
        this.cxjg = cxjg;
    }

    public Date getSqsj() {
        return sqsj;
    }

    public void setSqsj(Date sqsj) {
        this.sqsj = sqsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.4-20240111.033807-1214-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCxsq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
 * @version 1.0, 2017/5/10
 * @description 不动产查询申请
 */
@Table(name = "bdc_cxsq")
public class BdcCxsq implements Serializable{

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询申请主键
     */
    @Id
    private String cxsqid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 项目主键
     */
    private String proid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 工作流ID
     */
    private String wiid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人
     */
    private String sqr;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请人证件号码
     */
    private String sqrzjhm;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询目的
     */
    private String cxmd;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询条件
     */
    private String cxtj;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询内容
     */
    private String cxnr;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询凭证
     */
    private String cxpz;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 查询结果
     */
    private String cxjg;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请时间
     */
    private Date sqsj;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 备注
     */
    private String bz;

    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @description 申请材料
     */
    private String sqcl;

    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @description 坐落
     */
    private String zl;

    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @description 不动产权证号
     */
    private String bdcqzh;

    public String getCxsqid() {
        return cxsqid;
    }

    public void setCxsqid(String cxsqid) {
        this.cxsqid = cxsqid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSqr() {
        return sqr;
    }

    public void setSqr(String sqr) {
        this.sqr = sqr;
    }

    public String getSqrzjhm() {
        return sqrzjhm;
    }

    public void setSqrzjhm(String sqrzjhm) {
        this.sqrzjhm = sqrzjhm;
    }

    public String getCxmd() {
        return cxmd;
    }

    public void setCxmd(String cxmd) {
        this.cxmd = cxmd;
    }

    public String getCxtj() {
        return cxtj;
    }

    public void setCxtj(String cxtj) {
        this.cxtj = cxtj;
    }

    public String getCxnr() {
        return cxnr;
    }

    public void setCxnr(String cxnr) {
        this.cxnr = cxnr;
    }

    public String getCxpz() {
        return cxpz;
    }

    public void setCxpz(String cxpz) {
        this.cxpz = cxpz;
    }

    public String getCxjg() {
        return cxjg;
    }

    public void setCxjg(String cxjg) {
        this.cxjg = cxjg;
    }

    public Date getSqsj() {
        return sqsj;
    }

    public void setSqsj(Date sqsj) {
        this.sqsj = sqsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSqcl() {
        return sqcl;
    }

    public void setSqcl(String sqcl) {
        this.sqcl = sqcl;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }
}
